summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2014-02-16 12:05:41 -0600
committerDarrell Anderson <humanreadable@yahoo.com>2014-02-16 12:05:41 -0600
commitbfe2615471f3de55215e59b45ed677d15e19b688 (patch)
tree6438289f61965374e87035c9f164813659cddc6d
parentdd73caa65d933da6576ede49ffb20b9a0cb07b60 (diff)
downloadtdemultimedia-bfe26154.tar.gz
tdemultimedia-bfe26154.zip
Fix unintended renaming
-rw-r--r--kscd/libwm/scsi.c36
-rw-r--r--mpeglib/lib/decoder/mpgPlugin.cpp2
-rw-r--r--mpeglib/lib/mpegplay/mpegSystemStream.cpp2
-rw-r--r--mpeglib/lib/mpegplay/mpegVideoStream.cpp8
-rw-r--r--mpeglib/lib/mpegplay/startCodes.h4
-rw-r--r--mpeglib/lib/mpegplay/videoDecoder.cpp6
-rw-r--r--noatun/modules/winskin/waShadeMapping.h8
-rw-r--r--noatun/modules/winskin/waSkin.cpp4
-rw-r--r--noatun/modules/winskin/waSkinMapping.h8
-rw-r--r--noatun/modules/winskin/waSkins.h8
10 files changed, 43 insertions, 43 deletions
diff --git a/mpeglib/lib/decoder/mpgPlugin.cpp b/mpeglib/lib/decoder/mpgPlugin.cpp
index 510accbd..fd7170c8 100644
--- a/mpeglib/lib/decoder/mpgPlugin.cpp
+++ b/mpeglib/lib/decoder/mpgPlugin.cpp
@@ -95,7 +95,7 @@ void MpgPlugin::decoder_loop() {
//cout << "still initializing system stream"<<endl;
} else {
// if we have found a raw stream,
- // make sure we pass as first argument a SETQ_START_CODE
+ // make sure we pass as first argument a SEQ_START_CODE
if (mpegSystemHeader->getLayer() == _PACKET_SYSLAYER) {
lSysLayer=true;
mpegStreamPlayer->processSystemHeader(mpegSystemHeader);
diff --git a/mpeglib/lib/mpegplay/mpegSystemStream.cpp b/mpeglib/lib/mpegplay/mpegSystemStream.cpp
index d4ec43a6..ca25d7e8 100644
--- a/mpeglib/lib/mpegplay/mpegSystemStream.cpp
+++ b/mpeglib/lib/mpegplay/mpegSystemStream.cpp
@@ -68,7 +68,7 @@ int MpegSystemStream::firstInitialize(MpegSystemHeader* mpegHeader) {
}
mpegHeader->setHeader(syncCode);
- // SETQ_START_CODE: 1b3
+ // SEQ_START_CODE: 1b3
if (mpegHeader->hasRAWHeader()) {
// If we found a seq_heade_start code we assume
// that we are a video only stream
diff --git a/mpeglib/lib/mpegplay/mpegVideoStream.cpp b/mpeglib/lib/mpegplay/mpegVideoStream.cpp
index 8ce1defd..5e16b116 100644
--- a/mpeglib/lib/mpegplay/mpegVideoStream.cpp
+++ b/mpeglib/lib/mpegplay/mpegVideoStream.cpp
@@ -48,7 +48,7 @@ int MpegVideoStream::firstInitialize(MpegVideoHeader* mpegHeader) {
fill_videoBuffer(mpegSystemHeader);
lHasStream=true;
}
- // now find SETQ_START_CODE
+ // now find SEQ_START_CODE
hasBytes(4);
mpegVideoBitWindow->flushByteOffset();
@@ -70,8 +70,8 @@ int MpegVideoStream::firstInitialize(MpegVideoHeader* mpegHeader) {
int MpegVideoStream::isStartCode(unsigned int data) {
switch(data) {
- case SETQ_END_CODE:
- case SETQ_START_CODE:
+ case SEQ_END_CODE:
+ case SEQ_START_CODE:
case GOP_START_CODE:
case PICTURE_START_CODE:
case SLICE_MIN_START_CODE:
@@ -125,7 +125,7 @@ int MpegVideoStream::nextPIC() {
unsigned int data=showBits(32);
if ( (data != PICTURE_START_CODE) &&
(data != GOP_START_CODE) &&
- (data != SETQ_START_CODE) ) {
+ (data != SEQ_START_CODE) ) {
flushBits(8);
return false;
}
diff --git a/mpeglib/lib/mpegplay/startCodes.h b/mpeglib/lib/mpegplay/startCodes.h
index 1164fe4e..c305a39f 100644
--- a/mpeglib/lib/mpegplay/startCodes.h
+++ b/mpeglib/lib/mpegplay/startCodes.h
@@ -29,8 +29,8 @@
/* Start codes. */
-#define SETQ_END_CODE 0x000001b7
-#define SETQ_START_CODE 0x000001b3
+#define SEQ_END_CODE 0x000001b7
+#define SEQ_START_CODE 0x000001b3
#define GOP_START_CODE 0x000001b8
#define PICTURE_START_CODE 0x00000100
#define SLICE_MIN_START_CODE 0x00000101
diff --git a/mpeglib/lib/mpegplay/videoDecoder.cpp b/mpeglib/lib/mpegplay/videoDecoder.cpp
index 427e06c2..b1971795 100644
--- a/mpeglib/lib/mpegplay/videoDecoder.cpp
+++ b/mpeglib/lib/mpegplay/videoDecoder.cpp
@@ -121,7 +121,7 @@ int VideoDecoder::mpegVidRsrc(PictureArray* pictureArray) {
mpegVideoStream->flushBits(32);
packet->read_sys(data,vid_stream->bufferReader);
*/
- case SETQ_END_CODE:
+ case SEQ_END_CODE:
case ISO_11172_END_CODE: /* handle ISO_11172_END_CODE too */
/* Display last frame. */
@@ -148,11 +148,11 @@ int VideoDecoder::mpegVidRsrc(PictureArray* pictureArray) {
mpegVideoStream->next_start_code();
break;
- case SETQ_START_CODE:
+ case SEQ_START_CODE:
/* Sequence start code. Parse sequence header. */
if (ParseSeqHead() == false) {
- printf("SETQ_START_CODE 1-error\n");
+ printf("SEQ_START_CODE 1-error\n");
goto error;
}
goto done;
diff --git a/noatun/modules/winskin/waShadeMapping.h b/noatun/modules/winskin/waShadeMapping.h
index a20fcf6d..d28d4ca8 100644
--- a/noatun/modules/winskin/waShadeMapping.h
+++ b/noatun/modules/winskin/waShadeMapping.h
@@ -107,10 +107,10 @@ static const SkinDesc shadeMapFromFile[] = {
{_WA_FILE_SHUFREP, 69, 61, 23, 12}, // _WA_SKIN_SHUFREP_PLAYLIST_NOT_SET_PRES
{_WA_FILE_SHUFREP, 23, 73, 23, 12}, // _WA_SKIN_SHUFREP_PLAYLIST_SET_NORM
{_WA_FILE_SHUFREP, 73, 23, 12}, // _WA_SKIN_SHUFREP_PLAYLIST_SET_PRES
- {_WA_FILE_SHUFREP, 0, 61, 23, 12}, // _WA_SKIN_SHUFREP_ETQ_NOT_SET_NORM
- {_WA_FILE_SHUFREP, 46, 61, 23, 12}, // _WA_SKIN_SHUFREP_ETQ_NOT_SET_PRES
- {_WA_FILE_SHUFREP, 0, 73, 23, 12}, // _WA_SKIN_SHUFREP_ETQ_SET_NORM
- {_WA_FILE_SHUFREP, 46, 73, 23, 12}, // _WA_SKIN_SHUFREP_ETQ_SET_PRES
+ {_WA_FILE_SHUFREP, 0, 61, 23, 12}, // _WA_SKIN_SHUFREP_EQ_NOT_SET_NORM
+ {_WA_FILE_SHUFREP, 46, 61, 23, 12}, // _WA_SKIN_SHUFREP_EQ_NOT_SET_PRES
+ {_WA_FILE_SHUFREP, 0, 73, 23, 12}, // _WA_SKIN_SHUFREP_EQ_SET_NORM
+ {_WA_FILE_SHUFREP, 46, 73, 23, 12}, // _WA_SKIN_SHUFREP_EQ_SET_PRES
{_WA_FILE_TEXT, 0, 0, 155, 18}, // _WA_SKIN_TEXT
{_WA_FILE_VOLUME, 0, 0, 68, 421}, // _WA_SKIN_VOLUME_BAR_ALL_BARS
{_WA_FILE_VOLUME, 0, 0, 68, 13}, // _WA_SKIN_VOLUME_BAR
diff --git a/noatun/modules/winskin/waSkin.cpp b/noatun/modules/winskin/waSkin.cpp
index 41770cbd..4cdef1ec 100644
--- a/noatun/modules/winskin/waSkin.cpp
+++ b/noatun/modules/winskin/waSkin.cpp
@@ -254,8 +254,8 @@ void WaSkin::createButtons()
repeat->setPixmapDownSelected(_WA_SKIN_SHUFREP_REPEAT_SET_PRES);
- eq->setPixmapUp(_WA_SKIN_SHUFREP_ETQ_NOT_SET_NORM);
- eq->setPixmapDown(_WA_SKIN_SHUFREP_ETQ_NOT_SET_PRES);
+ eq->setPixmapUp(_WA_SKIN_SHUFREP_EQ_NOT_SET_NORM);
+ eq->setPixmapDown(_WA_SKIN_SHUFREP_EQ_NOT_SET_PRES);
playlist->setPixmapUp(_WA_SKIN_SHUFREP_PLAYLIST_NOT_SET_NORM);
playlist->setPixmapDown( _WA_SKIN_SHUFREP_PLAYLIST_NOT_SET_PRES);
diff --git a/noatun/modules/winskin/waSkinMapping.h b/noatun/modules/winskin/waSkinMapping.h
index 37d56c08..a3dfc9c5 100644
--- a/noatun/modules/winskin/waSkinMapping.h
+++ b/noatun/modules/winskin/waSkinMapping.h
@@ -107,10 +107,10 @@ static const SkinDesc normalMapFromFile[] = {
{_WA_FILE_SHUFREP, 69, 61, 23, 12}, // _WA_SKIN_SHUFREP_PLAYLIST_NOT_SET_PRES
{_WA_FILE_SHUFREP, 23, 73, 23, 12}, // _WA_SKIN_SHUFREP_PLAYLIST_SET_NORM
{_WA_FILE_SHUFREP, 73, 23, 12}, // _WA_SKIN_SHUFREP_PLAYLIST_SET_PRES
- {_WA_FILE_SHUFREP, 0, 61, 23, 12}, // _WA_SKIN_SHUFREP_ETQ_NOT_SET_NORM
- {_WA_FILE_SHUFREP, 46, 61, 23, 12}, // _WA_SKIN_SHUFREP_ETQ_NOT_SET_PRES
- {_WA_FILE_SHUFREP, 0, 73, 23, 12}, // _WA_SKIN_SHUFREP_ETQ_SET_NORM
- {_WA_FILE_SHUFREP, 46, 73, 23, 12}, // _WA_SKIN_SHUFREP_ETQ_SET_PRES
+ {_WA_FILE_SHUFREP, 0, 61, 23, 12}, // _WA_SKIN_SHUFREP_EQ_NOT_SET_NORM
+ {_WA_FILE_SHUFREP, 46, 61, 23, 12}, // _WA_SKIN_SHUFREP_EQ_NOT_SET_PRES
+ {_WA_FILE_SHUFREP, 0, 73, 23, 12}, // _WA_SKIN_SHUFREP_EQ_SET_NORM
+ {_WA_FILE_SHUFREP, 46, 73, 23, 12}, // _WA_SKIN_SHUFREP_EQ_SET_PRES
{_WA_FILE_TEXT, 0, 0, 155, 18}, // _WA_SKIN_TEXT
{_WA_FILE_VOLUME, 0, 0, 68, 421}, // _WA_SKIN_VOLUME_BAR_ALL_BARS
{_WA_FILE_VOLUME, 0, 0, 68, 13}, // _WA_SKIN_VOLUME_BAR
diff --git a/noatun/modules/winskin/waSkins.h b/noatun/modules/winskin/waSkins.h
index 8e778525..f8d5f623 100644
--- a/noatun/modules/winskin/waSkins.h
+++ b/noatun/modules/winskin/waSkins.h
@@ -58,10 +58,10 @@
#define _WA_SKIN_SHUFREP_PLAYLIST_NOT_SET_PRES 29
#define _WA_SKIN_SHUFREP_PLAYLIST_SET_NORM 30
#define _WA_SKIN_SHUFREP_PLAYLIST_SET_PRES 31
-#define _WA_SKIN_SHUFREP_ETQ_NOT_SET_NORM 32
-#define _WA_SKIN_SHUFREP_ETQ_NOT_SET_PRES 33
-#define _WA_SKIN_SHUFREP_ETQ_SET_NORM 34
-#define _WA_SKIN_SHUFREP_ETQ_SET_PRES 35
+#define _WA_SKIN_SHUFREP_EQ_NOT_SET_NORM 32
+#define _WA_SKIN_SHUFREP_EQ_NOT_SET_PRES 33
+#define _WA_SKIN_SHUFREP_EQ_SET_NORM 34
+#define _WA_SKIN_SHUFREP_EQ_SET_PRES 35
#define _WA_SKIN_TEXT 36
diff --git a/kscd/libwm/scsi.c b/kscd/libwm/scsi.c
index b15a286f..d056fe34 100644
--- a/kscd/libwm/scsi.c
+++ b/kscd/libwm/scsi.c
@@ -48,14 +48,14 @@
#define SCMD_PLAY_AUDIO_MSF 0x47
#define SCMD_PAUSE_RESUME 0x4b
-#define SUBTQ_STATUS_INVALID 0x00
-#define SUBTQ_STATUS_PLAY 0x11
-#define SUBTQ_STATUS_PAUSE 0x12
-#define SUBTQ_STATUS_DONE 0x13
-#define SUBTQ_STATUS_ERROR 0x14
-#define SUBTQ_STATUS_NONE 0x15
-#define SUBTQ_STATUS_NO_DISC 0x17 /* Illegal, but Toshiba returns it. */
-#define SUBTQ_ILLEGAL 0xff
+#define SUBQ_STATUS_INVALID 0x00
+#define SUBQ_STATUS_PLAY 0x11
+#define SUBQ_STATUS_PAUSE 0x12
+#define SUBQ_STATUS_DONE 0x13
+#define SUBQ_STATUS_ERROR 0x14
+#define SUBQ_STATUS_NONE 0x15
+#define SUBQ_STATUS_NO_DISC 0x17 /* Illegal, but Toshiba returns it. */
+#define SUBQ_ILLEGAL 0xff
#define PAGE_AUDIO 0x0e
#define LEADOUT 0xaa
@@ -346,20 +346,20 @@ wm_scsi2_get_drive_status(struct wm_drive *d, int oldmode,
}
/* If we can't read status, the CD has been ejected. */
- buf[1] = SUBTQ_ILLEGAL;
+ buf[1] = SUBQ_ILLEGAL;
if (sendscsi(d, buf, sizeof(buf), 1, SCMD_READ_SUBCHANNEL, 2, 64, 1,
0, 0, 0, sizeof(buf) / 256, sizeof(buf) % 256, 0,0,0))
return (0);
switch (buf[1]) {
- case SUBTQ_STATUS_PLAY:
+ case SUBQ_STATUS_PLAY:
*mode = WM_CDM_PLAYING;
*track = buf[6];
*ind = buf[7];
*pos = buf[9] * 60 * 75 + buf[10] * 75 + buf[11];
break;
- case SUBTQ_STATUS_PAUSE:
+ case SUBQ_STATUS_PAUSE:
if (oldmode == WM_CDM_PLAYING || oldmode == WM_CDM_PAUSED)
{
*mode = WM_CDM_PAUSED;
@@ -374,13 +374,13 @@ wm_scsi2_get_drive_status(struct wm_drive *d, int oldmode,
break;
/*
* SUBTQ_STATUS_DONE is sometimes returned when the CD is idle,
* even though the spec says it should only be returned when an
* audio play operation finishes.
*/
- case SUBTQ_STATUS_DONE:
- case SUBTQ_STATUS_NONE:
- case SUBTQ_STATUS_INVALID:
+ case SUBQ_STATUS_DONE:
+ case SUBQ_STATUS_NONE:
+ case SUBQ_STATUS_INVALID:
if (oldmode == WM_CDM_PLAYING)
*mode = WM_CDM_TRACK_DONE;
else
@@ -390,16 +390,16 @@ wm_scsi2_get_drive_status(struct wm_drive *d, int oldmode,
/*
* This usually means there's no disc in the drive.
*/
- case SUBTQ_STATUS_NO_DISC:
+ case SUBQ_STATUS_NO_DISC:
break;
/*
* This usually means the user ejected the CD manually.
*/
- case SUBTQ_STATUS_ERROR:
+ case SUBQ_STATUS_ERROR:
break;
- case SUBTQ_ILLEGAL: /* call didn't really succeed */
+ case SUBQ_ILLEGAL: /* call didn't really succeed */
break;
default:
@@ -374,13 +374,13 @@ wm_scsi2_get_drive_status(struct wm_drive *d, int oldmode,
break;
/*
- * SUBTQ_STATUS_DONE is sometimes returned when the CD is idle,
+ * SUBQ_STATUS_DONE is sometimes returned when the CD is idle,
* even though the spec says it should only be returned when an
* audio play operation finishes.